<?php
/**
 * Piwik - free/libre analytics platform
 *
 * @link http://piwik.org
 * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
 *
 */
namespace Piwik\Plugins\Ecommerce\Reports;

use Piwik\Piwik;
use Piwik\Plugins\Ecommerce\Columns\ProductName;

class GetItemsName extends BaseItem
{
    protected function init()
    {
        parent::init();

        $this->name      = Piwik::translate('Goals_ProductName');
        $this->dimension = new ProductName();
        $this->order     = 31;

        $this->subcategoryId = 'Goals_Products';
    }
}
